# Vertical-Interpolation-MONARCH

**Vertical-Interpolation-MONARCH** is a tool developed to interpolate pollutant outputs from the MONARCH model, both at the surface and vertical layers. Its primary purpose is to create structured outputs for compatibility with the [Optical Tool](https://earth.bsc.es/gitlab/hnavarro/OpticalTool).

This tool is designed to run efficiently on the BSC Nord3v2 HPC cluster using MPI parallelization (`mpi4py`).

---

## 📁 Repository Structure

| File | Purpose |
|------|---------|
| `Interpv03.py` | Core interpolation module (reads, processes, saves CSV) |
| `vertint_mainv03.py` | Main workflow controller |
| `launch_job.cmd` | SLURM batch submission script |
| `variables_to_interpolate.py` | Defines pollutant variables for processing |
| `load_modules.sh` | HPC environment setup |
| `aeronet_stations.json` | Station coordinates template |

---

## ⚙️ Configuration

### SLURM Job Setup (`launch_job.cmd`)

Update the environment variables in this script to configure your job:

```bash
export EXPID="a8gu"                                   
export START_DATE="2018-01-01"                        
export END_DATE="2018-01-02"
export OUTPUT_DIR="/esarchive/scratch/hnavarro/ITest"
export STATION_FILE="aeronet_stations.json"
```

## Variable definition 

### Script (`variables_to_interpolate.py`)

brown_carbon = [
    "pm2p5brc",
    "RH",
    "layer_thickness",
    "pm2p5bcphob",
    "pm2p5bcphil",
    "pm2p5pbrc",
    "pm2p5sbrc",
    "pm2p5poa",
    "pm2p5soa"
]

# Usage in 'vertint_mainv03.py': 

# variables = vti.brown_carbon  # Change to desired group

## Station file 

### Example (`aeronet_stations.json`)

{
    "Burjassot": {
      "lat": 39.507000,
      "lon": -0.420200
    },
    "Carpentras": {
      "lat": 44.083333,
      "lon": 5.058333
    },
    "Cluj_Ubb": {
      "lat": 46.768333,
      "lon": 23.551389
    }

}

# Submit Job
sbatch launch_job.cmd