#!/bin/bash
#SBATCH --job-name=vert_interp
#SBATCH --output=logs/vert_int_%j.out
#SBATCH --error=logs/vert_int_%j.err
#SBATCH --time=14:00:00
#SBATCH --nodes=1                 
#SBATCH --cpus-per-task=8

# Configuración flexible - el script calculará el número de tareas necesarias
export EXPID="a936"
export START_DATE="2018-01-01"
export END_DATE="2018-01-30"
export OUTPUT_DIR="/esarchive/scratch/hnavarro/ITest"
export STATION_FILE="aeronet_stations.json"

# Cargar módulos
module purge
source load_modules_dask.sh

# Obtener número de estaciones
NUM_STATIONS=$(python -c "import json; print(len(json.load(open('$STATION_FILE'))))")
echo "Total stations to process: $NUM_STATIONS"

# Configuración del cluster Dask
# Ajustar estos parámetros según los recursos disponibles
WORKERS_PER_NODE=8           # Debe coincidir con cpus-per-task
MEMORY_PER_WORKER="8GB"      # Memoria por worker (total = workers_per_node * memory_per_worker)

# Opcional: Escalar a múltiples nodos si es necesario
# TOTAL_WORKERS=$(( SLURM_JOB_NUM_NODES * WORKERS_PER_NODE ))

echo "Starting Dask cluster with:"
echo "- Workers per node: $WORKERS_PER_NODE"
echo "- Memory per worker: $MEMORY_PER_WORKER"

# Ejecutar el script Python con Dask
python -u vertint_mainv03_dask.py \
    --expid $EXPID \
    --start_date $START_DATE \
    --end_date $END_DATE \
    --output_dir $OUTPUT_DIR \
    --station_file $STATION_FILE

echo "Job $SLURM_JOB_ID completed successfully at $(date)" >> logs/vert_int_dask_${SLURM_JOB_ID}.status