#!/bin/bash
#SBATCH --job-name=vert_interp
#SBATCH --output=logs/vert_int_%j.out
#SBATCH --error=logs/vert_int_%j.err
#SBATCH --time=14:00:00
#SBATCH --account bsc32
#SBATCH --qos bsc_es

# Configuración flexible - el script calculará el número de tareas necesarias
export EXPID="a936"
export START_DATE="2018-01-01"
export END_DATE="2018-01-30"
export OUTPUT_DIR="/esarchive/scratch/hnavarro/ITest"
export STATION_FILE="aeronet_stations.json"

# Cargar módulos
module purge
source load_modules.sh

# get the number of tasks
if [ "$SLURM_PROCID" == "0" ]; then
    NUM_STATIONS=$(python -c "import json; print(len(json.load(open('$STATION_FILE'))))")
    echo "Total stations to process: $NUM_STATIONS"
    
    # Computing the number of tasks (max 48, min 1)
    MAX_TASKS=48  # customize this value based on your cluster
    REQ_TASKS=$(( NUM_STATIONS < MAX_TASKS ? NUM_STATIONS : MAX_TASKS ))
    
    # reconfigure (requiere sbcast en algunos clusters)
    scontrol update jobid=$SLURM_JOB_ID NumTasks=$REQ_TASKS
else
    #Other ranks wait for the first rank to finish
    sleep 5
fi

# Todos los ranks obtienen el número final de tareas
REQ_TASKS=$(scontrol show jobid=$SLURM_JOB_ID | grep -oP "NumTasks=\K\d+")

# Ejecutamos con el número calculado de tareas
srun --mpi=pmi2 --cpu-bind=cores --distribution=cyclic:cyclic \
    python -u vertint_mainv03.py \
    --expid $EXPID \
    --start_date $START_DATE \
    --end_date $END_DATE \
    --output_dir $OUTPUT_DIR \
    --station_file $STATION_FILE \

echo "Job $SLURM_JOB_ID completed successfully at $(date)" >> logs/vert_int_${SLURM_JOB_ID}.status
