import argparse
from datetime import date
from mpi4py import MPI
from Interpv03 import NetCDFVertInterp, load_stations
import variables_to_interpolate as vti

def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument('--expid', required=True)
    parser.add_argument('--start_date', required=True)
    parser.add_argument('--end_date', required=True)
    parser.add_argument('--output_dir', required=True)
    parser.add_argument('--station_file', required=True)
   # parser.add_argument('--variables', required=True)
    return parser.parse_args()

def main():
    args = parse_args()
    
    # Cargar estaciones
    stations = load_stations(args.station_file)
    
    comm = MPI.COMM_WORLD
    rank = comm.Get_rank()
    size = comm.Get_size()
    
    # Distribución de trabajo
    stations_per_task = len(stations) // size
    extra = len(stations) % size
    start_idx = rank * stations_per_task + min(rank, extra)
    end_idx = start_idx + stations_per_task + (1 if rank < extra else 0)
    my_stations = stations[start_idx:end_idx]
    variables = vti.brown_carbon

    # Procesar cada estación asignada
    for name, lat, lon in my_stations:
        try:
            if rank == 0:
                print(f"Processing station: {name}")
            
            # Inicializar interpolador para esta estación
            interpolator = NetCDFVertInterp(
                expid=args.expid,
                start_d=date.fromisoformat(args.start_date),
                end_d=date.fromisoformat(args.end_date),
                stn_lat=lat,
                stn_lon=lon
            )
            interpolator.save_data(
                        output_folder=args.output_dir,
                        station_name=name,
                        variables=variables  # Procesar una variable a la vez
                        )
                    
        except Exception as e:
            print(f"Rank {rank}: Error with station {name}: {str(e)}")

    comm.Barrier()
    if rank == 0:
        print("All processing completed!")

if __name__ == "__main__":
    main()
