import argparse
from datetime import date
import dask.bag as db
from Interpv03 import NetCDFVertInterp, load_stations
import variables_to_interpolate as vti
from dask.distributed import Client

def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument('--expid', required=True)
    parser.add_argument('--start_date', required=True)
    parser.add_argument('--end_date', required=True)
    parser.add_argument('--output_dir', required=True)
    parser.add_argument('--station_file', required=True)
    return parser.parse_args()

def process_station(args, station, variables):
    name, lat, lon = station
    try:
        print(f"Processing station: {name}")
        
        interpolator = NetCDFVertInterp(
            expid=args.expid,
            start_d=date.fromisoformat(args.start_date),
            end_d=date.fromisoformat(args.end_date),
            stn_lat=lat,
            stn_lon=lon
        )
        interpolator.save_data(
            output_folder=args.output_dir,
            station_name=name,
            variables=variables
        )
    except Exception as e:
        print(f"Error with station {name}: {str(e)}")
        raise  # Re-lanza la excepción para que Dask la capture

def main():
    args = parse_args()
    
    # Iniciar cliente Dask (puedes configurar según tu cluster HPC)
    # Para ejecución local:
    # client = Client(n_workers=8, threads_per_worker=1) 
    # Para cluster HPC (ejemplo SLURM):
    # from dask_jobqueue import SLURMCluster
    # cluster = SLURMCluster(cores=1, memory='4GB')
    # cluster.scale(8)  # Solicita 8 workers
    # client = Client(cluster)
    
    # Iniciar cliente Dask
    client = Client()
    
    # Cargar estaciones
    stations = load_stations(args.station_file)
    variables = vti.brown_carbon
    
    # Crear una bolsa Dask con las estaciones
    stations_bag = db.from_sequence(stations)
    
    # Procesar en paralelo
    (stations_bag
     .map(lambda station: process_station(args, station, variables))
     .compute())  # compute() inicia el procesamiento
    
    print("All processing completed!")
    
    # Cerrar el cliente Dask
    client.close()

if __name__ == "__main__":
    main()